import {Component, ComponentInterface, Element, Prop, h} from '@stencil/core';
import {CtaLinkButtonVariants} from '../../utils/utils';

@Component({
  tag: 'hy-cta-button',
  styleUrl: 'cta-button.scss',
  shadow: true,
})
export class CtaButton implements ComponentInterface {
  @Prop() variant: CtaLinkButtonVariants = CtaLinkButtonVariants.onBlueBkgd;
  @Prop() linkContent: string = '';
  @Prop() url?: string;
  @Prop() scLabel?: string;
  @Prop() isExternal: boolean = false;
  @Prop() headerstyle: string = 'common';
  @Element() el: HTMLElement;

  componentDidLoad() {
    let hyMainDiv = this.el.closest('.hy-main');
    if (hyMainDiv) {
      if (!hyMainDiv.classList.contains('with-sidebar')) {
        this.headerstyle = 'large';
      }
    }
  }

  render() {
    const classAttributes = ['hy-cta-button', this.variant, this.headerstyle].join(' ');

    const containerClassAttributes = ['hy-cta-button-container'].join(' ');

    const textClassAttributes = ['text'].join(' ');
    const iconClassAttributes = ['link-icon'].join(' ');

    const target = this.isExternal ? '_blank' : '_self';

    return (
      <span class={containerClassAttributes}>
        <a aria-label={this.scLabel} class={classAttributes} href={this.url} target={target}>
          <span class={textClassAttributes}>{this.linkContent.length === 0 ? <slot /> : this.linkContent}</span>
          <span class={iconClassAttributes}>
            <hy-icon icon={'hy-icon-arrow-right'} size={48} />
          </span>
        </a>
      </span>
    );
  }
}
