import {Component, Host, h, Prop, Watch} from '@stencil/core';

export interface IFilterGroupFilter {
  id: string | number;
  label: string;
}

@Component({
  tag: 'hy-filter-group',
  styleUrl: 'hy-filter-group.scss',
  shadow: false,
})
export class HyFilterGroup {
  private _filterGroupFilters: IFilterGroupFilter[];
  @Prop() filterGroupLabel: string;
  @Prop() filterGroupFilters: IFilterGroupFilter[] | string;

  @Watch('filterGroupFilters')
  arrayDataWatcher(newValue: IFilterGroupFilter[] | string) {
    if (typeof newValue === 'string') {
      this._filterGroupFilters = JSON.parse(newValue);
    } else {
      this._filterGroupFilters = newValue;
    }
  }

  componentWillLoad() {
    this.arrayDataWatcher(this.filterGroupFilters);
  }

  // TODO: Finish handleFilterDeselect functionality with real data.
  handleFilterDeselect(id) {
    console.log(id);
  }

  render() {
    return (
      <Host class="hy-filter-group">
        <ul class="hy-filter-group__listing">
          <li>
            <h3 class="hy-filter-group__label">{this.filterGroupLabel}</h3>
          </li>
          {this._filterGroupFilters.map(({id, label}, index) => (
            <hy-filter-group-item
              filter-group-item-id={id}
              filter-group-item-label={label}
              onClick={() => this.handleFilterDeselect(id)}
            >
              {this._filterGroupFilters.length > 1 && this._filterGroupFilters.length - 1 !== index && (
                <span class="hy-filter-group__divider">or</span>
              )}
            </hy-filter-group-item>
          ))}
        </ul>
      </Host>
    );
  }
}
